@@ -311,11 +311,13 @@ G - G-language Genome Analysis Environment core interface module
          (eg. .gbk => GenBank, .fasta => FASTA, .embl => EMBL)
 
          There are also several sample bacterial genomes included in the system.
-         $eco   = load("ecoli"); # Escherichia coli K12 MG1655 - NC_000913
-         $bsub  = load("bsub");  # Bacillus subtilis           - NC_000964
-         $mgen  = load("mgen");  # Mycoplasma genitalium       - NC_000908
-         $cyano = load("cyano"); # Synechococcus sp.           - NC_005070
-         $pyro  = load("pyro");  # Pyrococcus furiosus         - NC_003413
+         $eco   = load("ecoli");    # Escherichia coli K12 MG1655 - NC_000913
+         $bsub  = load("bsub");     # Bacillus subtilis           - NC_000964
+         $mgen  = load("mgen");     # Mycoplasma genitalium       - NC_000908
+         $cyano = load("cyano");    # Synechococcus sp.           - NC_005070
+         $pyro  = load("pyro");     # Pyrococcus furiosus         - NC_003413
+         $bbur  = load("bbur");     # Borrelia burgdorferi B31    - NC_001318
+         $plasF = load("plasmidf"); # Plasmid F                   - NC_002483
 
          Data can be automatically donwloaded from public databases using
          Uniform Sequence Address (USA) keys.
@@ -327,7 +329,8 @@ G - G-language Genome Analysis Environment core interface module
             $gb = load("genbank:AY063336")
             $gb = load("swiss:ROA1_HUMAN")
 
-         Second option specifies detailed actions.
+         Subsequent arguments work as options. Multiple options can be given 
+         in any order.
 
            'no msg'                  suprresses all STDOUT messages printed 
                                      when loading a database, including the
@@ -360,10 +363,12 @@ G - G-language Genome Analysis Environment core interface module
                                      Local installation of glimmer2 and setting
                                      of PATH environment value is required.
 
+           'Fasta'              this option loads a Fasta format database.
+           'Fastq'              this option loads a FastQ format database.
+           'EMBL'               this option loads a EMBL  format database.
+
                - following options require bioperl installation -
 
-           'Fasta'              this option loads a Fasta format database.
-           'EMBL'               this option loads a EMBL  format database.
            'swiss'              this option loads a swiss format database.
            'SCF'                this option loads a SCF   format database.
            'PIR'                this option loads a PIR   format database.
