@@ -38,13 +38,14 @@ use G::DB::SDB;
 use G::IO::Annotation;
 
 require G::IO::FastaI;
+require G::IO::FastQI;
 require G::IO::EmblI;
 
 use File::Basename;
 use File::ShareDir ':ALL';
 use autouse 'File::Temp'=>qw(tempfile);
 
-our $VERSION = '1.8.9';
+our $VERSION = '1.8.10';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -92,11 +93,13 @@ sub new {
 	$filename = dist_file('g-language', 'genomes/ecoli.gbk');
 	msg_error("WARNING: no genome file specified. Loading Escherichia coli K12 MG1655 genome as a sample.\n");
     }elsif(
-	   $filename eq 'ecoli' || 
-	   $filename eq 'bsub' || 
-	   $filename eq 'pyro' || 
-	   $filename eq 'mgen' || 
-	   $filename eq 'cyano'
+	   lc($filename) eq 'ecoli' || 
+	   lc($filename) eq 'bsub'  || 
+	   lc($filename) eq 'pyro'  || 
+	   lc($filename) eq 'mgen'  || 
+	   lc($filename) eq 'cyano' ||
+	   lc($filename) eq 'bbur'  ||
+	   lc($filename) eq 'plasmidf'
 	   ){
 	$filename = dist_file('g-language', "genomes/$filename.gbk");
     }
@@ -153,14 +156,17 @@ sub new {
 	}elsif ($opt =~ /net GenBank/){
 	    $netgbk = 1; 
 	    $format = 'net genbank';
-	}elsif (   lc($opt) eq 'fasta' || lc($opt) eq 'embl' 
-		|| lc($opt) eq 'swiss' || lc($opt) eq 'scf' 
-		|| lc($opt) eq 'pir'   || lc($opt) eq 'gcg' 
-		|| lc($opt) eq 'raw'   || lc($opt) eq 'ace'
-		|| lc($opt) eq 'game'  || lc($opt) eq 'phd'
-		|| lc($opt) eq 'qual'  || lc($opt) eq 'bsml' 
-		|| lc($opt) eq 'genbank'){
-	    $format = lc($opt);
+	}elsif (   $opt eq 'fasta' || $opt eq 'embl' 
+		|| $opt eq 'swiss' || $opt eq 'scf' 
+		|| $opt eq 'pir'   || $opt eq 'gcg' 
+		|| $opt eq 'raw'   || $opt eq 'ace'
+		|| $opt eq 'game'  || $opt eq 'phd'
+		|| $opt eq 'qual'  || $opt eq 'bsml' 
+		|| $opt eq 'fastq' || $opt eq 'genbank' ){
+	    $format = $opt;
+	    if($opt eq 'fastq' || $opt eq 'fasta'){
+		$no_cache = 1;
+	    }
 	}else{
 	    unless (lc($opt) eq 'net genbank'){
 		warn("Warning: Unknown Option $opt at \"new G\"\n");
@@ -218,6 +224,8 @@ sub new {
 	    $this = new G::IO::EmblI;
 	}elsif ($format eq 'fasta'){
 	    $this = new G::IO::FastaI;
+	}elsif ($format eq 'fastq'){
+	    $this = new G::IO::FastQI;
 	}elsif ($format ne 'genbank'){
 
 	    (undef, $outfile) = tempfile(undef, SUFFIX=>'.gbk');
@@ -345,9 +353,11 @@ sub multi_locus{
     do{
         my $F = 1;
         $lng = length($this->{"SEQ"});
-        $this->{"LOCUS$i"}   = $gb->{"LOCUS"};
-        $this->{"HEADER$i"}  = $gb->{"HEADER"};
-        $this->{"COMMENT$i"} = $gb->{"COMMENT"};
+        $this->{"LOCUS$i"}          = $gb->{"LOCUS"};
+	$this->{"LOCUS$i"}->{start} = $lng + 1;
+	$this->{"LOCUS$i"}->{end}   = $lng + 1 + length($gb->{SEQ});
+        $this->{"HEADER$i"}         = $gb->{"HEADER"};
+        $this->{"COMMENT$i"}        = $gb->{"COMMENT"};
 
         while(exists($gb->{"FEATURE$F"})){
             $this->{"FEATURE$f"}              = $gb->{"FEATURE$F"};
