@@ -151,7 +151,7 @@ sub read_locus{
 	    shift @locus_line;
 	    
 	    if ($#locus_line == 7){
-		$this->{"LOCUS"}->{"circular"} = 1;
+		$this->{"LOCUS"}->{"circular"} = $_ =~ /circular/ ? 1:0;
 		($this->{"LOCUS"}->{"id"},
 		 undef,
 		 undef,
@@ -161,7 +161,7 @@ sub read_locus{
 		 $this->{"LOCUS"}->{"length"}
 		 ) = @locus_line;
 	    }elsif ($#locus_line == 6){
-		$this->{"LOCUS"}->{"circular"} = 0;
+		$this->{"LOCUS"}->{"circular"} = $_ =~ /circular/ ? 1:0;
 		($this->{"LOCUS"}->{"id"},
 		 undef,
 		 undef,
@@ -171,7 +171,7 @@ sub read_locus{
 		 ) = @locus_line;
 	    }else{
 		msg_error("ERROR: Unknown LOCUS definition\n") if ($msg ne 'no msg');
-		$this->{"LOCUS"}->{"circular"} = 0;
+		$this->{"LOCUS"}->{"circular"} = $_ =~ /circular/ ? 1:0;
 	    }
 	}elsif(/^AC\s+(.*)\;/ && length($this->{LOCUS}->{id}) < 1){
 	    $this->{LOCUS}->{id} = $1;
