@@ -128,7 +128,7 @@ sub read_locus{
 	shift @locus_line;
 
 	if ($#locus_line == 6){
-	    $this->{"LOCUS"}->{"circular"} = 1;
+	    $this->{"LOCUS"}->{"circular"} = $_ =~ /circular/ ? 1:0;
 	    ($this->{"LOCUS"}->{"id"},
 	     $this->{"LOCUS"}->{"length"},
 	     undef,
@@ -137,7 +137,7 @@ sub read_locus{
 	     $this->{"LOCUS"}->{"type"},
 	     $this->{"LOCUS"}->{"date"}) = @locus_line;
 	}elsif ($#locus_line == 5){
-	    $this->{"LOCUS"}->{"circular"} = 0;
+	    $this->{"LOCUS"}->{"circular"} = $_ =~ /circular/ ? 1:0;
 	    ($this->{"LOCUS"}->{"id"},
 	     $this->{"LOCUS"}->{"length"},
 	     undef,
@@ -146,7 +146,7 @@ sub read_locus{
 	     $this->{"LOCUS"}->{"date"}) = @locus_line;
 	}else{
 	    msg_error("ERROR: Unknown LOCUS definition\n") if ($msg ne 'no msg');
-	    $this->{"LOCUS"}->{"circular"} = 0;
+	    $this->{"LOCUS"}->{"circular"} = $_ =~ /circular/ ? 1:0;
 	    $this->{"LOCUS"}->{"id"} = shift @locus_line;
 	}
 	last;
@@ -249,7 +249,7 @@ sub read_features{
 		    $line = $_;
 		    $linenum = tell GENBANK;
 		    $linenum -= length($line);
-		    last if($line =~ /\//);
+		    last if($line =~ /\// || $line =~ /ORIGIN/ || $line =~ /^ {5}\S+/);
 		    $fth .= $line;
 		}
 		seek GENBANK, $linenum, 0;
@@ -276,6 +276,16 @@ sub read_features{
 		$this->{"FEATURE$num"}->{"type"} = "partial_$key";
 		$this->{"FEATURE$num"}->{"partial"} = $feature;
 		msg_error("Partial feature: $feature\n");
+	    }elsif (/complement\((contig\d+)\:(\d+)\.\.(\d+)\)/){
+		$this->{"FEATURE$num"}->{"direction"} = "complement";
+		$this->{"FEATURE$num"}->{"start"} = $2;
+		$this->{"FEATURE$num"}->{"end"} = $3;
+		$this->{"FEATURE$num"}->{"contig"} = $1;
+	    }elsif (/(contig\d+)\:(\d+)\.\.(\d+)/){
+		$this->{"FEATURE$num"}->{"direction"} = "direct";
+		$this->{"FEATURE$num"}->{"start"} = $2;
+		$this->{"FEATURE$num"}->{"end"} = $3;
+		$this->{"FEATURE$num"}->{"contig"} = $1;
 	    }elsif (/complement\((\d+)\.\.(\d+)\)/){
 		$this->{"FEATURE$num"}->{"direction"} = "complement";
 		$this->{"FEATURE$num"}->{"start"} = $1;
@@ -307,7 +317,6 @@ sub read_features{
 	    }else{
 		msg_error("Irregular location feature: $key $feature\n");
 	    }
-
 	}else{
 	    if (/\/(\w+)=\"([^\"]+)\"/){
 		if(length($this->{"FEATURE$num"}->{"$1"})){
@@ -330,7 +339,7 @@ sub read_features{
 		$tmp =~ s/\s+/ /g;
 		$tmp =~ s/ //g if ($tag eq 'translation');
 		$this->{"FEATURE$num"}->{$tag} = $tmp;
-	    }elsif (/\/(\w+)=([\d|\d+])/){
+	    }elsif (/\/(\w+)=(\d+)/){
 		$this->{"FEATURE$num"}->{$1} = $2;
 	    }elsif (/\/(\w+)=\((.*)\)/){
 		my $key = $1;
