@@ -30,6 +30,8 @@
 package G::IO::Handler;
 
 use strict;
+use Carp;
+
 use G::Messenger;
 use G::Seq::Primitive;
 use G::DB::SDB;
@@ -200,6 +202,10 @@ sub find {
 
 
 sub getseq {
+    if (scalar(@_) < 3){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $start = shift;
     my $end = shift;
@@ -219,10 +225,18 @@ sub getseq {
 }
 
 sub get_gbkseq {
+    if (scalar(@_) < 3){
+	carp("Not enough arguments.");
+	return;
+    }
     return getseq($_[0], $_[1] - 1, $_[2] - 1, $_[3]);
 }
 
 sub get_cdsseq {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $object = shift;
 
@@ -243,6 +257,10 @@ sub get_cdsseq {
 }
 
 sub around_startcodon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $gb = shift;
     my $cds = shift;
     my $before = shift || 0;
@@ -257,6 +275,10 @@ sub around_startcodon {
 }
 
 sub around_stopcodon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $gb = shift;
     my $cds = shift;
     my $before = shift || 0;
@@ -271,6 +293,10 @@ sub around_stopcodon {
 }
 
 sub before_startcodon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $object = shift;
     my $length = shift || 100;
@@ -288,6 +314,10 @@ sub before_startcodon {
 }
 
 sub after_startcodon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $object = shift;
     my $length = shift || 100;
@@ -305,6 +335,10 @@ sub after_startcodon {
 }
 
 sub before_stopcodon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $object = shift;
     my $length = shift || 100;
@@ -322,6 +356,10 @@ sub before_stopcodon {
 }
 
 sub after_stopcodon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $object = shift;
     my $length = shift || 100;
@@ -339,14 +377,26 @@ sub after_stopcodon {
 }
 
 sub startcodon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     return substr($_[0]->get_geneseq($_[1]), 0, 3);
 }
 
 sub stopcodon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     return substr($_[0]->get_geneseq($_[1]), -3, 3);
 }
 
 sub pos2feature {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $pos = shift;
     my $pos2 = shift;
@@ -379,10 +429,18 @@ sub pos2feature {
 }
 
 sub gene2id {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     return length($_[0]->{$_[1]}->{feature}) ? 'FEATURE' . $_[0]->{$_[1]}->{feature} : '';
 }
 
 sub feature2id {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $gene = shift;
 
@@ -397,6 +455,10 @@ sub feature2id {
 }
 
 sub pos2gene {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $pos = shift;
     my $pos2 = shift;
@@ -424,6 +486,10 @@ sub pos2gene {
 }
 
 sub get_geneseq {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $object = shift;
 
@@ -439,6 +505,10 @@ sub get_geneseq {
 }
 
 sub get_intron {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $cds = shift;
 
@@ -461,6 +531,10 @@ sub get_intron {
 }
 
 sub get_exon {
+    if (scalar(@_) < 2){
+	carp("Not enough arguments.");
+	return;
+    }
     my $this = shift;
     my $cds = shift;
 
@@ -495,7 +569,9 @@ sub seq_info {
     msg_send(sprintf "\n\nAccession Number: %s\n", $this->{LOCUS}->{id}) if(length($this->{LOCUS}->{id}));
     $msg .= sprintf "\n  Length of Sequence : %9d\n" , $length;
 
-    if($others > $a + $t + $g + $c){
+    if($length == 0){
+	$msg .= sprintf "\n  No Sequence Found.\n\n";
+    }elsif($others > $a + $t + $g + $c){
         $msg .= sprintf "\n  This is Amino Acid Sequence. Try amino_info().\n\n";
     }else{
         $msg .= sprintf "           A Content : %9d (%.2f\%)\n" , $a , $a / $length * 100;
@@ -553,10 +629,10 @@ sub rRNA {
     my $this = shift;
     my $option = shift;
 
-    if($option =~ /\d+S/){
+    if($option =~ /\d+S|SSU|LSU/){
 	my %rRNA;
 
-	foreach ($this->feature()){
+	foreach ($this->feature('rRNA')){
 	    if($this->{$_}->{product} =~ /([0-9\.]+S)/i){
 		push(@{$rRNA{uc($1)}}, $_);
 	    }elsif($this->{$_}->{gene} =~ /rrf/){
@@ -578,9 +654,10 @@ sub rRNA {
 	    }
 	}
 
-	my @result = sort {length($this->get_geneseq($b))<=>length($this->get_geneseq($a))} @{$rRNA{$option}};
-
-	return wantarray ? @result : $result[0];
+	if(defined $rRNA{$option}){
+	    my @result = sort {length($this->get_geneseq($b))<=>length($this->get_geneseq($a))} @{$rRNA{$option}};
+	    return wantarray ? @result : $result[0];
+	}
     }else{
 	return feature($this, 'rRNA', $option);
     }
@@ -741,7 +818,7 @@ sub relocate_origin{
     my $tmp = shift;
     my $gb = $tmp->clone();
     my $pos = shift;
-    die("New start position \(in Perl coordinate\) must be given.\n") unless($pos =~ /\d/);
+    croak("New start position \(in Perl coordinate\) must be given.\n") unless($pos =~ /\d/);
 
     $this->{LOCUS} = $gb->{LOCUS};
     $this->{HEADER} = $gb->{HEADER};
@@ -891,7 +968,7 @@ sub _interpret_format {
 	return 'bioperl';
     }elsif ($filename =~ /^(.*?):(.*)/){
 	unless(lc($1) =~ /(swiss|genbank|genpept|embl|refseq)/){
-	    die("Unsupported database name for USA. Supported databases are\n" .
+	    croak("Unsupported database name for USA. Supported databases are\n" .
 		"swiss, genbank, genpept, embl, or refseq\n");
 	}
 	return "usa";
@@ -899,6 +976,8 @@ sub _interpret_format {
 	return 'genbank';
     }elsif (lc($filename) =~ /\.(fasta|fast|seq|fst|fa|fsa|nt|aa|ffn|fna)/i){
 	return 'fasta';
+    }elsif (lc($filename) =~ /\.(fastq|fq)/i){
+	return 'fastq';
     }elsif ($filename =~ /^NC_\d+$/i){
 	return 'RefSeq';
     }elsif ($filename =~ /^NP_\d+$/i){
@@ -912,8 +991,21 @@ sub _interpret_format {
 	if (length $format){
 	    return $format;
 	}else{
-	    warn("Unknown file format. Interpreting $filename as GenBank...\n");
-	    return 'genbank';
+	    open(FILE, $filename);
+	    while(<FILE>){
+		if(/^>/){
+		    return 'fasta';
+		}elsif(/^LOCUS/){
+		    return 'genbank';
+		}elsif(/^ID/){
+		    return 'embl';
+		}else{
+		    carp("Unknown file format. Interpreting $filename as GenBank...\n");
+		    return 'genbank';
+		}
+		last;
+	    }
+	    close(FILE);
 	}
     }
 }
@@ -936,6 +1028,7 @@ sub output {
 	    my ($fh, $outfile) = tempfile(undef, SUFFIX=>'.gbk');
 	    $gb->make_gb($outfile);
 	    $in = read_sequence($outfile);
+	    unlink($outfile);
 	}
 
 	write_sequence(">$file", $option, $in);
