@@ -28,11 +28,15 @@
 package G::Messenger;
 
 use strict;
+use Carp;
 use base 'Exporter';
 use autouse 'Cwd'=>qw(getcwd);
 use autouse 'Data::Dumper'=>qw(Dumper);
 use autouse 'LWP::Simple'=>qw(get);
 
+use SubOpt;
+use G::IO;
+
 our @EXPORT = qw(
 	     msg_interface
 	     msg_ask_interface
@@ -102,30 +106,64 @@ sub say{
     #with URL
     @text = readFile('http://togows.dbcls.jp/entry/pubmed/12538262')
 
+    #with FastA/FastQ files
+    %sequences = readFile($fasta.fasta);
+    # key corresponds to the header line, value to the sequence.
+    # quality information for FastQ file is thrown away.
+
  Options:
-    none
+    Specify second argument as 1 to chomp each lines.
+
+    -format      'plain' to read as plain text, 'url' to read as url,
+                 'fasta' for FASTA file, 'fastq' for FASTQ file.
+                 Usually the format is automatically interpreted, but
+                 this option can be specified to force interpretation.
 
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+    20091202-01 added FastA/FastQ support
     20090520-01 added URL support
     20090313-01 initial posting
 
 =cut
 
 sub readFile{
-    my $file = shift;
-    my $chomp = shift || 0;
+    opt_default('format'=>'');
+    my @argv    = opt_get(@_);
+    my $file    = shift @argv;
+    my $chomp   = shift @argv || 0;
+    my $format  = lc(opt_val('format'));
+
+    unless($format){
+	if (lc($file) =~ /\.(fasta|fast|seq|fst|fa|fsa|nt|aa|ffn|fna)/i){
+	    $format = 'fasta';
+	}elsif (lc($file) =~ /\.(fastq|fq)/i){
+	    $format = 'fastq';
+	}elsif ($file =~ /\:\/\//){
+	    $format = 'url';
+	}
+    }
+
     my @result;
 
-    if($file =~ /\:\/\//){
+    if($format eq 'url'){
 	foreach my $line (split(/\n/, get($file))){
 	    $line .= "\n" unless($chomp);
 	    push(@result, $line);
 	}
+    }elsif($format eq 'fasta' || $format eq 'fastq'){
+	my %hash;
+
+	my $gb = new G::IO($file, 'no msg', 'no cache', $format);
+	do{
+	    $hash{$gb->{LOCUS}->{id}} = $gb->{SEQ};
+	}while($gb->next_locus('no msg'));
+
+	return %hash;
     }else{
-	open(FILE, $file) || die($!);
+	open(FILE, $file) || croak($!);
 	while(<FILE>){
 	    chomp if($chomp);
 	    push(@result, $_);
@@ -170,7 +208,7 @@ sub writeFile{
     my $data = shift;
     my $file = shift || "out.txt";
 
-    open(OUT, '>' . $file) || die($!);
+    open(OUT, '>' . $file) || croak($!);
     print OUT $data;
     close(OUT);
 
