@@ -135,16 +135,31 @@ sub mass{
     my $key = shift;
 
     my %mass = (
-		A=>82.09,  C=>121.16, D=>133.10, E=>147.13, F=>165.19, G=>75.07,
-		H=>155.16, I=>131.17, K=>146.19, L=>131.17, M=>149.21, N=>132.12,
-		P=>115.13, Q=>146.15, R=>174.20, S=>105.09, T=>119.12, V=>117.15,
-		W=>204.22, Y=>181.19
+		A=>89.09,  C=>121.16, D=>133.10, E=>147.13, F=>165.19,
+		G=>75.07,  H=>155.16, I=>131.17, K=>146.19, L=>131.17,
+		M=>149.21, N=>132.12, P=>115.13, Q=>146.15, R=>174.20,
+		S=>105.09, T=>119.12, V=>117.15, W=>204.22, Y=>181.19
 		);
 
     return $mass{$key} if (length $key);    
     return %mass;
 }
 
+sub hydropathy{
+    my $key = shift;
+
+    # Kyte J, Doolittle RF. A simple method for displaying the hydropathic character of a protein. J Mol Biol. 1982 157(1):105-32. 
+    my %hydropathy = (
+		      A=> 1.8, C=> 2.5, D=>-3.5, E=>-3.5, F=> 2.8,
+		      G=>-0.4, H=>-3.2, I=> 4.5, K=>-3.9, L=> 3.8,
+		      M=> 1.9, N=>-3.5, P=>-1.6, Q=>-3.5, R=>-4.5,
+		      S=>-0.8, T=>-0.7, V=> 4.2, W=>-0.9, Y=>-1.3
+		      );
+    
+    return $hydropathy{$key} if (length $key);    
+    return %hydropathy;
+}
+
 sub one2three{
     my $key = shift;
 
@@ -152,7 +167,8 @@ sub one2three{
 		      A=>"Ala", B=>"Asx", C=>"Cys", D=>"Asp", E=>"Glu", F=>"Phe",
 		      G=>"Gly", H=>"His", I=>"Ile", K=>"Lys", L=>"Leu", M=>"Met",
 		      N=>"Asn", P=>"Pro", Q=>"Gln", R=>"Arg", S=>"Ser", T=>"Thr",
-		      V=>"Val", W=>"Trp", X=>"Xxx", Y=>"Tyr", Z=>"Glx"
+		      V=>"Val", W=>"Trp", X=>"Xaa", Y=>"Tyr", Z=>"Glx",
+		      U=>"Sec", '/'=>"TER"
 		      );
 
     return $one2three{$key} if (length $key);
