@@ -46,7 +46,7 @@ our @EXPORT = qw(
 	     consensus_z
 );
 
-__DATA__
+#__DATA__
 
 #::::::::::::::::::::::::::::::
 #     Perldoc
@@ -108,6 +108,7 @@ sub base_counter{
 		if($start-1-$i>0){
 		    $hash[$upstream-$i]{kazu}++;
 		    $nuc=$gb->getseq($start-1-$i,$start-1-$i+$PatLen);
+		    next if(length($nuc != $PatLen));
 		    $hash[$upstream-$i]{$nuc}++;
 		    $hash[0]{pat}{$nuc}++;
 		}
@@ -141,7 +142,7 @@ sub base_counter{
     $hash[0]{upstream}=$upstream;
     $hash[0]{downstream}=$downstream;
     $hash[0]{PatLen}=$PatLen;
-    $hash[0]{gbk}=$gb;
+#    $hash[0]{gbk}=$gb;
     $hash[0]{pos}=$position;
 
     if($output eq "f"){
@@ -169,7 +170,7 @@ sub _base_printer{
     my $PatLen=$$hash[0]{PatLen};
     my $upstream=$$hash[0]{upstream};
     my $downstream=$$hash[0]{downstream};
-    my $gb=$$hash[0]{gbk};
+#    my $gb=$$hash[0]{gbk};
     my $position=$$hash[0]{pos};
     my $i;
     my $j;
