@@ -422,7 +422,7 @@ sub leading_strand {
    -keto        use keto skew for calculation (default: 0)
    -at          use AT skew for calculation (default: 0)
    -p           calculate p-value when GCSI version 2 is selected (default: 0)
-                returned values are ($gcsi, $sa, $dist, $p)
+                returned values are ($gcsi, $sa, $dist, $z, $p)
 
   References:
     1. Arakawa K, Tomita M (2007) "The GC skew index: a measure of genomic compositional 
@@ -843,6 +843,7 @@ sub genomicskew {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
  History:
+   20091007-01 changed to disregard N or X bases
    20070429-01 minor bug fix related to output=>"f" option
    20060711-01 added purine and keto options
    20010905-01 updated options
@@ -855,7 +856,7 @@ sub genomicskew {
 
 sub gcwin  {
     &opt_default(window=>10000, at=>0, purine=>0, keto=>0, output=>"show", 
-		 application=>"gimv", filename=>"gcwin.png");
+		 application=>"gimv", filename=>"gcwin.png", skipGap=>0);
     my @args = opt_get(@_);
 
     my $gb = opt_as_gb(shift @args);
@@ -864,6 +865,7 @@ sub gcwin  {
     my $at = opt_val("at");
     my $purine = opt_val("purine");
     my $keto = opt_val("keto");
+    my $skip = opt_val("skipGap");
     my $application = opt_val("application");
     my $filename = opt_val("filename");
     $filename =~ s/\.png$/\.csv/ if (opt_val("output") eq 'f');
@@ -872,24 +874,38 @@ sub gcwin  {
     my $j;
     
     my $i = 0;
-    my ($g, $c);
+    my ($g, $c, $rest);
     while(length($$ref) - ($window * $i) >= $window){
         if($at){
             $g = substr($$ref, $window * $i, $window) =~ tr/a/a/;
             $c = substr($$ref, $window * $i, $window) =~ tr/t/t/;
+	    $rest =  substr($$ref, $window * $i, $window) =~ tr/g/g/;
+	    $rest += substr($$ref, $window * $i, $window) =~ tr/c/c/;
         }elsif($purine){
             $g = substr($$ref, $window * $i, $window) =~ tr/g/g/;
             $c = substr($$ref, $window * $i, $window) =~ tr/a/a/;
+	    $rest =  substr($$ref, $window * $i, $window) =~ tr/t/t/;
+	    $rest += substr($$ref, $window * $i, $window) =~ tr/c/c/;
         }elsif($keto){
             $g = substr($$ref, $window * $i, $window) =~ tr/g/g/;
             $c = substr($$ref, $window * $i, $window) =~ tr/t/t/;
+	    $rest =  substr($$ref, $window * $i, $window) =~ tr/a/a/;
+	    $rest += substr($$ref, $window * $i, $window) =~ tr/c/c/;
 	}else{
             $g = substr($$ref, $window * $i, $window) =~ tr/g/g/;
             $c = substr($$ref, $window * $i, $window) =~ tr/c/c/;
+	    $rest =  substr($$ref, $window * $i, $window) =~ tr/a/a/;
+	    $rest += substr($$ref, $window * $i, $window) =~ tr/t/t/;
         }
+	$rest += $g + $c;
 
-	$gcwin[$i] = sprintf("%.6f",($g+$c)/$window);
+	if($rest == 0 && $skip){
+	    $gcwin[$i] = $gcwin[$i - 1];
+	}else{
+	    $gcwin[$i] = $rest >= 1 ? sprintf("%.6f",($g+$c)/$rest) : 0;
+	}
 	$location[$i] = $i * $window;
+
 	$i ++;
     }
     $i --;
