@@ -66,8 +66,8 @@ G::Seq::Operon - Retrieves operon information for bacterial genoms
 
   Description:
     This program retrieves the operon information from 
-      1. RegulonDB for Escherichia coli K12
-      2. Operon Database for other bacteria
+      1. RegulonDB for Escherichia coli K12 chromosome
+      2. DOOR for other bacteria and plasmids
     and annotation to the given genome data. 
 
     Two attributes are added to each CDS hash.
@@ -89,13 +89,14 @@ G::Seq::Operon - Retrieves operon information for bacterial genoms
       of Escherichia coli K-12 beyond transcription, active (experimental) annotated 
       promoters and Textpresso navigation.", Nucleic Acids Res. 1;36(Database issue):D120-4
 
-   2. Okuda S et al. "ODB: a database of operons accumulating known operons across multiple genomes."
-      Nucleic Acids Res  2006 Jan 1;34(Database issue):D358-62
+   2. Mao F et al. (2009) "DOOR: a database for prokaryotic operons", 
+      Nucleic Acids Res. 1;37(Database issue):D459-D463
 
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+   20090322-01 added support for DOOR (stopped using Operon Database)
    20090313-01 added support for other organisms using Operon Database
    20090313-02 modified to match latest version of RegulonDB format (6.0)
    20070829-01 patched to match latest version of RegulonDB formamt
@@ -174,36 +175,37 @@ sub set_operon {
 	    $gb->{$cds}->{operonN} = 0 unless(length $gb->{$cds}->{operon});
 	}
 
-   }else{
+    }else{
+	my $url = 'http://csbl1.bmb.uga.edu/OperonDB/downloadNCoperon.php?NC_id=' . $gb->{LOCUS}->{id};
+	my $dir = $ENV{HOME} . '/.glang/data/Operon' . $gb->{LOCUS}->{id} . '.txt';
+	mirror($url, $dir);
+	die("No Operon data for this species.\n\n") unless(-e $dir);
 
-       my $url = 'http://www.g-language.org/db/operon/' . $gb->{LOCUS}->{id} . '.csv';
-       my $dir = $ENV{HOME} . '/.glang/data/Operon' . $gb->{LOCUS}->{id} . '.txt';
-       mirror($url, $dir);
-       die("No Operon data for this species.\n\n") unless(-e $dir);
-       
-       my $flag = 0;
-       open(FILE, $dir) || die($!);
-       while (<FILE>) {
-	   chomp;
-	   my ($operonName, $operonNum, @operons) = split(/\,/, $_);
-	   my @list = @operons;
+	my $data = {};
+	open(FILE, $dir) || die($!);
+	while (<FILE>) {
+	    chomp;
+	    my ($operonName, $gi, $gene, undef) = split(/\s+/, $_, 4);
+	    push(@{$data->{$operonName}}, $gene);
+	}
+	close(FILE);
 
-	   @list = reverse(@operons) if($gb->{$operons[0]}->{direction} eq 'complement');
-
-	   my $i = 1;
-	   foreach my $cds (@list){
-	       $cds =~ s/BG/BSU/g if($gb->{LOCUS}->{id} eq 'NC_000964');
-	       $gb->{$cds}->{operon} = $operonName;
-	       $gb->{$cds}->{operonN} = $i;
-	       $i ++;
-	   }
-       }
-       close(FILE);
-
-       foreach my $cds ($gb->cds()){
-	   $gb->{$cds}->{operonN} = 0 unless(length $gb->{$cds}->{operon});
-       }
-   }
+	foreach my $operonName (keys %{$data}){
+	    my @list = @{$data->{$operonName}};
+	    @list = reverse(@operons) if($gb->{$operons[0]}->{direction} eq 'complement');
+	    
+	    my $i = 1;
+	    foreach my $cds (@list){
+		$gb->{$cds}->{operon} = $operonName;
+		$gb->{$cds}->{operonN} = $i;
+		$i ++;
+	    }
+	}
+	
+	foreach my $cds ($gb->cds()){
+	    $gb->{$cds}->{operonN} = 0 unless(length $gb->{$cds}->{operon});
+	}
+    }
 
     return $gb;
 }
