@@ -38,8 +38,9 @@ use base qw(Exporter);
 use SelfLoader;
 
 our @EXPORT = qw(
-	     palindrome
 	     signature
+	     signature_dist	 
+	     palindrome
 	     oligomer_search
 	     oligomer_counter
 	     find_pattern
@@ -93,14 +94,14 @@ __DATA__
    NULL = &signature(G instance);
 
   Options:
-   -output      output option (default: 'stdout')
-                'stdout' for standard output,
-                'f' for file output in directory "data"
-   -filename    output filename (default: 'signature.csv')
-   -wordlength  word length (default: 2)
-   -start       start position (default: 1)
-   -end         end position (default: 0)
-                0 for using whole genome sequence; i.e. -end=>length($gb->{SEQ});
+   -output     output option (default: 'stdout')
+               'stdout' for standard output,
+               'f' for file output
+   -filename   output filename (default: 'signature.csv')
+   -wordlength       word length (default: 2)
+   -start      start position (default: 1)
+   -end        end position (default: 0)
+               0 when using whole genome sequence; i.e. -end=>length($gb->{SEQ});
 
   Author: 
    Haruo Suzuki (haruo@g-language.org)
@@ -120,7 +121,7 @@ __DATA__
 =cut
 
 sub signature {
-    &opt_default(output=>'stdout',filename=>'signature.csv',wordlength=>2,start=>1,end=>0);
+    &opt_default(output=>'stdout', filename=>'signature.csv', wordlength=>2, start=>1, end=>0);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
     my $output = opt_val("output");
@@ -134,26 +135,29 @@ sub signature {
     my %oe;
 
     $end = length($gb->{SEQ}) unless($end);
-    my $seq = $gb->getseq($start, $end);
-    my $seq2 = reverse($seq);    
+    #my $seq1 = $gb->getseq($start, $end); # Perl coordinates
+    my $seq1 = $gb->get_gbkseq($start, $end); # GenBank coordinates
+
+    my $seq2 = reverse($seq1);    
     $seq2 =~ tr
 	[acgturymkdhbvwsn]
 	[tgcaayrkmhdvbwsn];
 
-    for(my $i; $i < length($seq) - $wordlength; $i ++){
-	$mono{substr($seq, $i, 1)} ++;
-	$mono{substr($seq2, $i, 1)} ++;
-	$obs{substr($seq, $i, $wordlength)} ++;
+    $seqb = $seq1.$seq2;
+    $mono{a} = $seqb =~ tr/a/a/;
+    $mono{c} = $seqb =~ tr/c/c/;
+    $mono{g} = $seqb =~ tr/g/g/;
+    $mono{t} = $seqb =~ tr/t/t/;
+    my $total = $seqb =~ tr/acgt/acgt/;
+    foreach (keys %mono){ $mono{$_} =  $mono{$_} / $total; }
+
+    for(my $i = 0; $i < length($seq1) - $wordlength + 1; $i ++){
+	$obs{substr($seq1, $i, $wordlength)} ++;
 	$obs{substr($seq2, $i, $wordlength)} ++;
     }
-
-    my $total; 
-    foreach (keys %mono){ $total += $mono{$_}; }
-    foreach (keys %mono){ $mono{$_} =  $mono{$_} / $total; }
     $total = 0;
-    foreach (keys %obs){ $total += $obs{$_}; }
+    foreach (keys %obs){ delete $obs{$_} if($_ =~ /[^acgt]/); $total += $obs{$_}; }
     foreach (keys %obs){ $obs{$_} =  $obs{$_} / $total; }
-    foreach (keys %obs){ delete $obs{$_} if($_ =~ /[^acgt]/); }
     foreach (keys %obs){
 	$exp{$_} = 1;
 	for(my $i = 0; $i < $wordlength; $i ++){ $exp{$_} *= $mono{substr($_,$i,1)}; }
@@ -171,27 +175,143 @@ sub signature {
 	@allkey = @tmp;
     }
     @allkey = sort @allkey;
-		     
-    if($output =~ /stdout/){
-	msg_send("\n\nstart\tend\t"); foreach(@allkey){ msg_send("$_\t"); }
-	msg_send("\n$start\t$end\t"); foreach(@allkey){ msg_send("$oe{$_}\t"); }
+
+    #####
+    if(0){
+	my %hashslice;
+	@hashslice{@allkey} = undef;
+	foreach my $key (sort keys %hashslice){ 
+	    my $key2 = reverse($key); $key2 =~ tr [atgc][tacg];
+	    if($key ne $key2 && exists $hashslice{$key}){
+		$hashslice{"$key/$key2"} = undef;
+		delete $hashslice{$key};
+		delete $hashslice{$key2};
+		$oe{"$key/$key2"} = sprintf("%.3f", ($oe{$key} + $oe{$key2})/2 );
+		delete $oe{$key};
+		delete $oe{$key2};
+	    }
+	}
+	@allkey = sort keys %hashslice;
+	$gb->{"$start..$end"}->{signature} = \%oe; # input in the G instance
     }
+    ##### 
+
+    my $GC = $seq1 =~ tr/gcGC/gcGC/; $GC = sprintf "%.1f", 100 * $GC / length($seq1);
+    
+    if($output =~ /stdout/){
+	msg_send("\n\nstart\tend\tG+C\t"); foreach(@allkey){ msg_send("$_\t"); }
+	msg_send("\n$start\t$end\t$GC\t"); foreach(@allkey){ msg_send("$oe{$_}\t"); }
+    }
+
     if($output eq 'f'){
-	mkdir ("data", 0777);
-	open(FILE,">>data/$filename");
-	#open(FILE,">>$filename");
+	#mkdir ("data", 0777);
+	#open(FILE,">>data/$filename");
+	open(FILE,">>$filename");
 	unless($gb->{"header_signature"}){
-	    print FILE "start,end,";
+	    print FILE "start,end,G+C,";
 	    foreach(@allkey){ print FILE "$_,"; }
 	    $gb->{"header_signature"} = 1;
+	    print FILE "\n";
         }
-	print FILE "\n$start,$end,";
+	print FILE "$start,$end,$GC,";
 	foreach(@allkey){ print FILE (exists $oe{$_}) ? "$oe{$_}," : "0,"; }
+	print FILE "\n";
 	close(FILE);
     }
 }
 
 
+=head2 signature_dist
+
+  Name: signature_dist   -   calculate genomic signature difference
+
+  Description:
+   This program computes and returns the dissimilarity (distance) and 
+   similarity (P-value) in genomic signature between plasmid and chromosome.
+
+  Usage: 
+   ($distance, $p_value) = &signature_dist($gb_plasmid, $gb_chromosome);
+
+  Options:
+   -output   output option (default: 'stdout')
+   -wordlength     word length (default: 2)
+   -window   size (bp) of sliding window by which sequences are sampled (default: 5000)
+   -step     step size (bp) of sliding window (default: 5000)
+   -method   the distance measure to be used. (default: 'mahalanobis')
+             This must be one of "euclidean", "delta" or "mahalanobis". 
+
+  Examples:
+   &signature_dist($gb_plasmid, $gb_chromosome, -wordlength=>2, -window=>50000, -method=>'delta');
+   calculates the average absolute dinucleotide relative abundance difference (delta-distance) 
+   between a plasmid and non-overlapping 50-kb chromosomal segments (Campbell A et al., 1999).
+
+  Author: 
+   Haruo Suzuki (haruo@g-language.org)
+
+  History:
+   20090327 initial posting
+
+  References:
+   Campbell A et al. (1999) Proc Natl Acad Sci U S A. 96(16):9184-9.
+   Suzuki H et al. (2008) Nucleic Acids Res. 36(22):e147.
+
+  Requirements: sub signature()
+
+=cut
+
+sub signature_dist {
+    &opt_default(output=>'stdout', wordlength=>2, window=>5000, step=>5000, method=>'mahalanobis');
+    my @args = opt_get(@_);
+    my $query = opt_as_gb(shift @args);
+    my $sbjct = opt_as_gb(shift @args);
+    my $output = opt_val("output");
+    my $wordlength = opt_val("wordlength");
+    my $window = opt_val("window");
+    my $step = opt_val("step");
+    my $method = opt_val("method");
+
+    system('echo -n > query.csv > sbjct.csv');
+    &signature($query, -output=>"f", -filename=>'query.csv', -wordlength=>$wordlength);
+    for(my $i = 1; $i <= length($sbjct->{SEQ}) - $window; $i += $step){ &signature($sbjct, -output=>"f", -filename=>'sbjct.csv', -wordlength=>$wordlength, -start=>$i, -end=>$i+$window); }
+    
+    my $rcmd = new Rcmd;
+    my @result = $rcmd->exec(
+			     qq/
+			     method = "$method"
+			     f = "query.csv"
+			     X = read.csv(f)
+			     X = X[,-c(1,2,3,length(X))]
+			     f = "sbjct.csv"
+			     Y = read.csv(f)
+			     Y = Y[,-c(1,2,3,ncol(Y))]
+			     if(method == "mahalanobis"){ 
+                                 library(MASS);
+                                 dX = try(mahalanobis(X, apply(Y,2,mean), ginv(var(Y)), inverted=TRUE), silent=TRUE);
+                                 dY = try(mahalanobis(Y, apply(Y,2,mean), ginv(var(Y)), inverted=TRUE), silent=TRUE);
+                                 #dX = try(mahalanobis(X, apply(Y,2,mean), var(Y)), silent=TRUE);
+                                 #dY = try(mahalanobis(Y, apply(Y,2,mean), var(Y)), silent=TRUE);
+			     } else if(method == "delta"){
+				 dX = dist(rbind(apply(Y,2,mean),X), method="manhattan") * ncol(Y)^-1 * 1000;
+				 dY = dist(rbind(apply(Y,2,mean),Y), method="manhattan")[1:nrow(Y)] * ncol(Y)^-1 * 1000;
+			     } else {
+				 dX = dist(rbind(apply(Y,2,mean),X), method=method);
+				 dY = dist(rbind(apply(Y,2,mean),Y), method=method)[1:nrow(Y)];
+			     }
+			     dX = ifelse(is.numeric(dX), dX, NA)
+			     D = dX
+			     P = ifelse(is.numeric(dY), mean(dY > dX), NA)
+			     as.vector(c(D, P))
+			     /
+			     );
+#    print "@result \n";
+    my $distance = sprintf "%.4f", shift @result;
+    my $p_value = sprintf "%.4f", shift @result;
+#    system('rm query.csv sbjct.csv');
+    &msg_send("\n$wordlength-mer genomic signature difference:\n $method distance = $distance\n p-value = $p_value\n") if ($output eq 'stdout');
+    return ($distance, $p_value);
+}
+
+
 
 =head2 palindrome
 
@@ -852,7 +972,9 @@ sub nucleotide_periodicity {
                "gmap" for zoomable image using Google Maps API (default: show)    
 
   References:
-    1. Almeida JS, Carrico JA, Maretzek A, Noble PA, Fletcher M (2001) 
+    1. Arakawa K, Oshita K, Tomita M (2009) "A web server for interactive and
+       zoomable Chaos Game Representation images", Source Code for Biol Med., 4:6.
+    2. Almeida JS, Carrico JA, Maretzek A, Noble PA, Fletcher M (2001) 
        "Analysis of genomic sequences by Chaos Game Representation." 
        Bioinformatics. 17(5):429-437.
   
@@ -1156,7 +1278,9 @@ sub kmer_table {
                "gmap" for zoomable image using Google Maps API (default: show)    
 
   References:
-    1. Almeida JS, Carrico JA, Maretzek A, Noble PA, Fletcher M (2001) 
+    1. Arakawa K, Oshita K, Tomita M (2009) "A web server for interactive and
+       zoomable Chaos Game Representation images", Source Code for Biol Med., 4:6.
+    2. Almeida JS, Carrico JA, Maretzek A, Noble PA, Fletcher M (2001) 
        "Analysis of genomic sequences by Chaos Game Representation." 
        Bioinformatics. 17(5):429-437.
   
