@@ -40,6 +40,7 @@ our @EXPORT = qw(
 	     translate
 	     splitprintseq
 	     to_fasta
+	     to_fastq
 	     shuffleseq
 	     DoubleHelix
 );
@@ -87,9 +88,47 @@ my %CodonTable = (
 #    Let the code begin...
 #::::::::::::::::::::::::::::::
 
+=head2 translate
+
+  Name: translate  -   translate nucleotide sequence to amino acid sequence
+
+  Description:
+    This method translates a given nucleotide sequence into amino acid 
+    sequence, using standard codon table. Change to the codon table or
+    custom codon table can be supplied as optional arguments. Stop codons
+    are denoted by '/' by default.
+    
+  Usage : 
+    $amino = translate($nucleotide);
+
+    # to set stop codons to 'X'
+    $amino = translate($nucleotide, tga=>"X", taa=>"X", tag=>"X");
+
+    # to use custom codon table
+    $amino = translate($nucleotide, %customCodonTable);
+
+ Options:
+    Custom codon table can be optionally used (see above).
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+    20091203-01 added cutom codon table option
+    20010727-01 initial posting
+
+=cut
+
 
 sub translate {
     my $seq = lc(shift);
+    my %option = @_;
+
+    my %codons = %CodonTable;
+    foreach my $key (%option){
+	$codons{$key} = $option{$key};
+    }
+
     my $amino = '';
 
     while(3 <= length($seq)){
@@ -98,7 +137,7 @@ sub translate {
 	if ($codon =~ /[^atgc]/){
 	    $amino .= 'X';
 	}else{
-	    $amino .= $CodonTable{$codon};
+	    $amino .= $codons{$codon};
 	}
     }
 
@@ -183,7 +222,7 @@ sub splitprintseq {
     -length      number of characters per line (default: 60)
     -filename    output filename (default: "out.fasta")
     -output      "f" to output to file, and return the fasta as a string.
-                 "return" to just return the fasta as a string
+                 "return" to just return the fasta as a string (default: "return")
 
   Author: 
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
@@ -196,7 +235,7 @@ sub splitprintseq {
 =cut
 
 sub to_fasta{
-    SubOpt::opt_default(length=>60, filename=>"out.fasta", name=>"sequence", output=>"f");
+    SubOpt::opt_default(length=>60, filename=>"out.fasta", name=>"sequence", output=>"return");
     my @args = SubOpt::opt_get(@_);
     my $first = shift @args;
     die("Error: No sequence passed to to_fasta") unless(length($first));
@@ -221,6 +260,63 @@ sub to_fasta{
 
 
 
+=head2 to_fastq
+
+  Name: to_fastq   -   output given sequence to a FASTQ file
+
+  Description:
+    This method outputs the given sequence as a FASTQ file. If the given sequence
+    object does not contain $file->{QUAL} section, 'X' is used for quality score
+    (corresponding to 50 in Phred quality).
+    
+  Usage : 
+    $fastq_string = to_fastq($seq, -name=>"My sequence"); # output the sequence to out.fasta
+
+ Options:
+    -name        string for FASTQ header (default: sequence)
+                 if the first argument is an instance of new G(), 
+                 $gb->{LOCUS}->{id} is used as default
+    -length      number of characters per line (default: 60)
+    -filename    output filename (default: "out.fastq")
+    -output      "f" to output to file, and return the fasta as a string.
+                 "return" to just return the fasta as a string (default: "return")
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+    20091201-01 initial posting
+
+=cut
+
+sub to_fastq{
+    SubOpt::opt_default(length=>75, filename=>"out.fastq", name=>"sequence", output=>"return");
+    my @args = SubOpt::opt_get(@_);
+    my $first = shift @args;
+    die("Error: No sequence passed to to_fastq") unless(length($first));
+    my $gb = SubOpt::opt_as_gb($first);
+    my $filename = SubOpt::opt_val("filename");
+    my $name = SubOpt::opt_val("name");
+    my $length = SubOpt::opt_val("length");
+    my $output = SubOpt::opt_val("output");
+
+    $name = $gb->{LOCUS}->{id} if($name eq 'sequence' && length $gb->{LOCUS}->{id});
+    $gb->{QUAL} = 'X' x length($gb->{SEQ}) unless(length($gb->{QUAL}));
+
+    if($output eq 'f'){
+	open(OUT, ">$filename") || die($!);
+	printf OUT "\@%s\n%s\+%s\n%s", $name, splitprintseq(uc($gb->{SEQ}), $length), $name, splitprintseq($gb->{QUAL}, $length);
+	close(OUT);
+	return sprintf "\@%s\n%s\+%s\n%s", $name, splitprintseq(uc($gb->{SEQ}), $length), $name, splitprintseq($gb->{QUAL}, $length);
+    }else{
+	return sprintf "\@%s\n%s\+%s\n%s", $name, splitprintseq(uc($gb->{SEQ}), $length), $name, splitprintseq($gb->{QUAL}, $length);
+    }
+}
+
+
+
+
+
 =head2 shuffleseq
 
   Name: shuffleseq   -   create randomized sequence with conserved k-mer composition
