@@ -28,10 +28,12 @@ package G::Tools::Alignment;
 
 use SubOpt;
 use G::Messenger;
+use G::Seq::Primitive;
 
 use strict;
-use base qw(Exporter);
 use SelfLoader;
+use base qw(Exporter);
+use autouse 'File::Temp'=>qw(tempfile);
 
 our @EXPORT = qw(
 		 _clustalw
@@ -39,6 +41,7 @@ our @EXPORT = qw(
 		 _blast
 		 _formatdb
 		 blastall
+		 blat
 		 );
 
 __DATA__
@@ -274,6 +277,49 @@ __HELP__
 
 
 
+sub blat {
+    my @argv = opt_get(@_);
+    my $db   = shift @argv;
+    my $tmp  = shift @argv;
+    my %data = opt_val();
+
+    if(-e $tmp){
+
+    }else{
+	my $seq  = opt_as_gb($tmp);
+	my($fh, $fname) = tempfile();
+	to_fasta($seq, -filename=>$fname, -output=>"f");
+	$tmp = $fname;
+    }
+
+    my $option = '';
+    foreach my $key (keys %data){
+	next if($key =~ /[qidentity|tidentity]/);
+	$option .= "-$key=$data{$key} ";
+    }
+
+    my @result;
+    foreach my $line (`blat $db $tmp stdout $option`){
+	chomp($line);
+	next unless($line =~ /^\d/);
+
+	my @res = split (/\t/, $line);
+
+	if($data{qidentity}){
+	    next unless($res[0]/$res[10] >= $data{qidentity}/100);
+	}
+	if($data{tidentity}){
+	    next unless($res[0]/$res[14] >= $data{tidentity}/100);
+	}
+	push(@result, [@res]);
+    }
+
+    return @result;
+}
+
+
+
+
     
 
 sub _blast{  
