@@ -211,7 +211,7 @@ sub generateGMap{
   <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
     <title>Google Map View of $name - generated by G-language GAE</title>
 
-    <script src="http://maps.google.com/maps?file=api&amp;v=2&amp;key=$apikey"
+    <script src="http://maps.google.com/maps?file=api&amp;v=2.156&amp;key=$apikey"
             type="text/javascript" charset="utf-8"></script>
     <script src="http://googlemaps.googlermania.com/gmapkit/api?js=gmapkitmapcontrols3d.js" type="text/javascript"></script>
 
@@ -364,6 +364,7 @@ __HTML__
 		 }
 
 		for (i = 0; i <= sequences.length; i ++){ 
+	    if(sequences[i] == null){continue;}
 	     var width = 4096/Math.pow(2, seq.length - 1);
 	     var ud = sequences[i];
 	     var rl = sequences[i];
