@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2008 Keio University
+#     Copyright (C) 2001-2009 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 # G-language GAE is free software; you can redistribute it and/or
@@ -35,6 +35,7 @@ use base qw(Exporter);
 use SelfLoader;
 
 our @EXPORT = qw(
+		 cumulative
 		 mean
 		 sum
 		 variance
@@ -91,6 +92,41 @@ This library is a part of G-language GAE.
 #    Let the code begin...
 #::::::::::::::::::::::::::::::
 
+
+=head2 cumulative
+
+  Name: cumulative   -   returns cumulative array of the given array
+
+  Description:
+    Returns the cumulative array of the data.
+
+  Usage:
+    @cumulative = cumulative(@array_of_values);
+
+  Options:
+    None.
+
+  Author: 
+    Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
+
+  History:
+   20081124-01 initial posting
+
+=cut
+
+sub cumulative {
+    my @array;
+    my $cum;
+    foreach my $val (@_){
+	$cum += $val;
+	push(@array, $cum);
+    }
+
+    return @array;
+}
+
+
+
 =head2 mean
 
   Name: mean   -   calculate the mean of the given array of data
