@@ -29,7 +29,7 @@
 
 package SubOpt;
 
-use G::Messenger;
+use Carp;
 require G::IO;
 
 use strict;
@@ -43,7 +43,7 @@ our @EXPORT = qw(
 		 opt_as_gb
 );
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 #::::::::::::::::::::::::::::::
 #          Variables
@@ -69,7 +69,7 @@ sub opt_as_gb {
     return if ($opt_list);
 
     if ($#_ >= 1){
-	&msg_error("Error 1 in SubOpt::opt_as_gb():\n  Given value is not a valid sequence.\n");
+	croak("Error 1 in SubOpt::opt_as_gb():\n  Given value is not a valid sequence.\n");
 	return '';
     }elsif (length $_[0] < 1){
 	return lastInstance G::IO();
@@ -86,7 +86,7 @@ sub opt_as_gb {
 	if (defined $unknown->{SEQ}){
 	    return $unknown;
 	}else{
-	    &msg_error("Error 3 in SubOpt::opt_as_gb():\n  Given value is not a valid sequence.\n");
+	    croak("Error 3 in SubOpt::opt_as_gb():\n  Given value is not a valid sequence.\n");
 	    return '';
 	}
     } elsif (ref $unknown eq 'SCALAR') {
@@ -99,7 +99,7 @@ sub opt_as_gb {
 	$new_gb->{SEQ} = lc($unknown);
 	return $new_gb;
     }else{
-	&msg_error("Error 4 in SubOpt::opt_as_gb():\n  Given value is not a valid sequence.\n");
+	croak("Error 4 in SubOpt::opt_as_gb():\n  Given value is not a valid sequence.\n");
 	return '';
     }
 }
@@ -108,7 +108,7 @@ sub opt_as_gb {
 sub opt_default{
     %data = (@_);
 
-    die if ($opt_list);
+    croak if ($opt_list);
 }
 
 sub opt_val{
@@ -233,6 +233,11 @@ SubOpt - G-language Subroutine Input API
         #This is for the prevention of the confusion of SubOpt name space
         #in case SubOpt is called in cascade.
 
+    When this function is called without any arguments, it returns the
+    entire option-value hash.
+
+    eg. my %options = opt_val();
+
   opt_as_gb(<$gb or $seq>) 
     This method automatically distinguish the variable from
     a scalar sequence, reference of a sequence, and a G instance,
